summaryrefslogtreecommitdiffstats
path: root/kalzium/src/eqchemview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalzium/src/eqchemview.h')
-rw-r--r--kalzium/src/eqchemview.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kalzium/src/eqchemview.h b/kalzium/src/eqchemview.h
index c0b88f9c..38bc380e 100644
--- a/kalzium/src/eqchemview.h
+++ b/kalzium/src/eqchemview.h
@@ -48,7 +48,7 @@ public:
/**
* Default constructor
*/
- eqchemView(TQWidget *tqparent);
+ eqchemView(TQWidget *parent);
/**
* Destructor
@@ -92,9 +92,9 @@ class EQChemDialog : public KDialogBase
/**
* public constructor
*
* @param tqparent the tqparent widget
*/
- EQChemDialog( TQWidget *tqparent );
+ EQChemDialog( TQWidget *parent );
private slots:
/**
@@ -92,9 +92,9 @@ class EQChemDialog : public KDialogBase
* public constructor
*
- * @param tqparent the tqparent widget
+ * @param parent the parent widget
*/